function [res] = svmperfAlgorithm(Xtrain, ytrain, Xtest, ytest, C, t_train, t_test)

ytrain = ytrain(:);
ytest = ytest(:);

assert(size(Xtrain,2)==size(Xtest,2));
assert(size(Xtrain,1)==size(ytrain,1));
assert(size(Xtest,1)==size(ytest,1));

opt_str = sprintf('-c %d -w 3 -l 10 -v 0 -e 0.5', C);

if issame(sort(unique(ytrain)), [0;1])
    ytrain = 2*(ytrain-0.5);
    ytest = 2*(ytest-0.5);
end

% let's suppose you have your data in input_data and input_labels
modelperf=svmperflearn(Xtrain, ytrain, opt_str);

predictions_train = svmperfclassify(Xtrain, ytrain, modelperf, '-v 0');
predictions_test = svmperfclassify(Xtest, ytest, modelperf, '-v 0');
    
[~, ~, auc_roc] = show_roc_curve(1, ytest, predictions_test, false);
[~, ~, auc_roc_train] = show_roc_curve(1, ytrain, predictions_train, false);

if(exist('t_train', 'var'))
    res.train_ci = concordance_index(t_train, ytrain, -predictions_train);
end

if(exist('t_test', 'var'))
    res.test_ci = concordance_index(t_test, ytest, -predictions_test);
end

err_train = sum((predictions_train>0) ~= (ytrain==1))/length(ytrain);
err_test = sum((predictions_test>0) ~= (ytest==1))/length(ytest);

res.train_acc = 1 - err_train;
res.test_acc = 1 - err_test;

res.test_auc = auc_roc;
res.train_auc = auc_roc_train;

res.precision = sum(predictions_test>0 & ytest==1)/sum(predictions_test>0);
res.recall = sum(predictions_test>0 & ytest==1)/sum(ytest==1);


return